Package: util-linux
Version: 2.20.1-5.3
Severity: important
Tags: patch
Usertags: usrinitramfs etcinitramfs

The attached patch is to apply for jessie, so isn't appropriate
to use until after wheezy is released.  See
http://wiki.debian.org/ReleaseGoals/MountUsrInInitramfs
for further information.

To summarise, the intent is to mount /usr (and potentially also
/etc for certain specialised use cases) in the initramfs, so that
/usr is available as soon as init starts.

The fsck -R option ignores filesystems which are mounted when
checkfs runs.  Currently this is only the rootfs (plus special
filesystems which aren't checked).  With /usr (and /etc) mounted
early, the -R option therefore needs extending to support these
filesystems as well so that we check them manually in checkroot,
and skip them in checkfs.

The upload of this change will need coordinating with the
initramfs-tools and sysvinit packages so that we get the
dependencies correct so that usr is checked (and only checked
once, not zero or twice).


Thanks,
Roger

-- System Information:
Debian Release: wheezy/sid
  APT prefers testing
  APT policy: (500, 'testing')
Architecture: i386 (i686)

Kernel: Linux 2.6.32.33-kvm-i386-20111128-dirty (SMP w/1 CPU core)
Locale: LANG=en_GB.UTF-8, LC_CTYPE=en_GB.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash

Versions of packages util-linux depends on:
ii  debconf [debconf-2.0]  1.5.48
ii  dpkg                   1.16.9
ii  initscripts            2.88dsf-34
ii  install-info           4.13a.dfsg.1-10
ii  libblkid1              2.20.1-5.3
ii  libc6                  2.13-37
ii  libncurses5            5.9-10
ii  libselinux1            2.1.9-5
ii  libslang2              2.2.4-15
ii  libtinfo5              5.9-10
ii  libuuid1               2.20.1-5.3
ii  lsb-base               4.1+Debian8
ii  tzdata                 2012j-1
ii  zlib1g                 1:1.2.7.dfsg-13

util-linux recommends no packages.

Versions of packages util-linux suggests:
pn  dosfstools           <none>
pn  kbd | console-tools  <none>
pn  util-linux-locales   <none>

-- debconf information excluded
--- util-linux-2.20.1.original/fsck/fsck.8	2012-12-25 15:14:40.000000000 +0000
+++ util-linux-2.20.1/fsck/fsck.8	2012-12-27 22:19:18.000000000 +0000
@@ -273,8 +273,8 @@
 .B \-R
 When checking all filesystems with the
 .B \-A
-flag, skip the root filesystem.  (This is useful in case the root
-filesystem has already been mounted read-write.)
+flag, skip the root, /etc and /usr filesystems.  (This is useful in case the root,
+/etc and/or /usr filesystems have already been mounted read-write.)
 .TP
 .B \-T
 Don't show the title on startup.
--- util-linux-2.20.1.original/fsck/fsck.c	2012-12-25 15:14:40.000000000 +0000
+++ util-linux-2.20.1/fsck/fsck.c	2012-12-27 22:18:20.000000000 +0000
@@ -1132,11 +1132,11 @@
 	}
 	/*
 	 * This is for the bone-headed user who enters the root
 	 * filesystem twice.  Skip root will skep all root entries.
 	 */
 	if (skip_root)
 		for (fs = filesys_info; fs; fs = fs->next)
-			if (!strcmp(fs->mountpt, "/"))
+			if (!strcmp(fs->mountpt, "/") || !strcmp(fs->mountpt, "/etc") || !strcmp(fs->mountpt, "/usr"))
 				fs->flags |= FLAG_DONE;
 
 	while (not_done_yet) {
@@ -1132,11 +1132,11 @@
 	/*
 	 * This is for the bone-headed user who enters the root
-	 * filesystem twice.  Skip root will skep all root entries.
+	 * filesystem twice.  Skip root will skep all root, /etc and /usr entries.
 	 */
 	if (skip_root)

Reply via email to